/**********************************************************************
 *$Component                                                          *
 *    void explab (input_label, output_label)                         *
 *$Abstract                                                           *
 *    Main program for the expand label utility                       *
 *$Keywords                                                           *
 *    DRIVER                                                          *
 *    TOOL_MAIN                                                       *
 *$Inputs                                                             *
 *    input_label:                                                    *
 *       The input_label variable is a character string containing the*
 *       name of a label to be used as the input label in any label   *
 *       processing task.                                             *
 *    output_label:                                                   *
 *       The output_label variable is a character string containing a *
 *       name of a label to be used as the input label in any label   *
 *       processing task.                                             *
 *$Outputs                                                            *
 *    None                                                            *
 *$Returns                                                            *
 *    None                                                            *
 *$Detailed_Description                                               *
 *    The expand label utility reads a PDS label, recursively         *
 *    includes all included labels by following the STRUCTURE         *
 *    references in the label, and writes out the expanded label.     *
 *    It also reports syntax errors found in any of the label files.  *
 *$External_References                                                *
 *    None                                                            *
 *$Author_and_Institution                                             *
 *    Marti D. DeMore/JPL                                             *
 *$Version_and_Date                                                   *
 *    1.1   September 10, 1992                                        *
 *$Change_history                                                     *
 *    MDD   05-20-92   Original generation.                           *
 *    MDD   09-10-92   Added warning in even of syntax errors         *
 **********************************************************************/


#include "pdsdef.h"
#include "pdsglob.h"
#include "label.h"
#include "labtool.h"

#define EXPLAB_VERSION   "1.1"

main (argc, argv)

int argc;
char *argv[];
{

  LOGICAL success = FALSE;
  AGGREGATE label_ptr = NULL;

/** BEGIN **/

  /*-----------------------------------------------------------------------*/
  /** Setup toolbox files                                                 **/
  /** IF number of arguments is correct THEN                              **/
  /*-----------------------------------------------------------------------*/

  /*printf("PDS Expand Label Utility - Version %s\n\n", EXPLAB_VERSION);*/
 
  lab_setup();
  if (argc == 3)
  {
     /*--------------------------------------------------------------------*/
     /** Read the input label and expand it                               **/
     /** IF it could be read THEN                                         **/
     /**    remove all STRUCTURE keywords                                 **/
     /**    write out the expanded label                                  **/
     /*--------------------------------------------------------------------*/

     printf ("Processing file %s...\n\n", argv [1]);
     label_ptr = lt_read_expanded_label (argv [1]);
     if (label_ptr != NULL) 
     {
         lt_global_keyword_change (label_ptr, "STRUCTURE", PDS_LAB_REMOVE, 
                                   NULL, NULL); 
         success = lab_write_label_or_template (label_ptr, DEFAULT_REC_TYPE,
                                                0, argv[2]);
     }
    
     /*--------------------------------------------------------------------*/
     /** ELSE                                                             **/
     /**    notify user file could not be read                            **/
     /*--------------------------------------------------------------------*/

     else
        printf ("Input label %s could not be found or is not a PDS label\n\n", 
                 argv[1]);

     /*--------------------------------------------------------------------*/
     /** ENDIF the label could be read...                                 **/
     /*--------------------------------------------------------------------*/
     
  }
  /*-----------------------------------------------------------------------*/
  /** ELSE                                                                **/
  /**    notify user arguments were incorrect                             **/
  /*-----------------------------------------------------------------------*/

  else
     printf ("Usage: explab <input-file> <output-file>\n");

  /*-----------------------------------------------------------------------*/
  /** ENDIF arguments are correct...                                      **/
  /** write out remaining messages                                        **/
  /** print success message, if needed, and clean up                      **/
  /*-----------------------------------------------------------------------*/

  lab_print_messages ();

  if (success && !lab_has_messages ())
     printf ("SUCCESS! Converted file %s was written to file %s\n\n", argv[1],
              argv[2]);
  else if (success && lab_has_messages ())
  {
     printf ("\nWARNING! Converted file %s was written to file %s,\n", argv[1],
              argv[2]);
     printf ("         but syntax errors were found in input labels.\n\n");
  }
  else
     printf ("\nERROR! Output file may not have been written.\n\n");
   
  lab_clear_messages ();
  lab_remove_label_or_template (label_ptr);
  lab_exit();
  return;

/** END **/
}

